<?php

/**
 * @file
 * Contains \Drupal\rut_field\Plugin\field\field_type\RutItem.
 */

namespace Drupal\rut_field\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;
use Drupal\rut\Rut;

/**
 * Plugin implementation of the 'rut_field_rut' field type.
 *
 * @FieldType(
 *   id = "rut_field_rut",
 *   label = @Translation("Rut Field"),
 *   module = "rut_field",
 *   description = @Translation("Field to store RUN or RUT."),
 *   default_widget = "rut_field_widget",
 *   default_formatter = "rut_field_formatter_default"
 * )
 */
class RutItem extends FieldItemBase {
  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return array(
      'columns' => array(
        'rut' => array(
          'type' => 'int',
          'not null' => FALSE,
          'unsigned' => TRUE,
          'size' => 'big',
        ),
        'dv' => array(
          'type' => 'char',
          'not null' => FALSE,
          'length' => 1,
        ),
      ),
      'indexes' => array(
        'rut' => array('rut'),
      ),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('rut')->getValue();

    return empty($value);
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['rut'] = DataDefinition::create('integer')
      ->setLabel(t('Rut value'));
    $properties['dv'] = DataDefinition::create('string')
      ->setLabel(t('Dv value'));

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue(FieldDefinitionInterface $field_definition) {
    list($rut, $dv) = Rut::generateRut(FALSE);

    $values = array(
      'rut' => $rut,
      'dv' => $dv,
    );

    return $values;
  }

}
